@@ -55,7 +55,7 @@ class AtlantisClient:
         response.raise_for_status()
         return response.json()
 
-    def validate_token(self, token):
+    def validate_token(self, id_token):
         """Valida token de acesso do usuário
 
         Exemplo:
@@ -67,8 +67,8 @@ class AtlantisClient:
             client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123')
             token_payload = client.validate_token('tokenJwT')
 
-        :param token: Token JWT do usuário gerado pelo Atlantis
-        :type token: str
+        :param id_token: Token JWT do usuário gerado pelo Atlantis
+        :type id_token: str
         :raises InvalidTokenError: Se o token estiver expirado ou alterado
         :return: Retorna o payload do token JWT
         :rtype: dict
@@ -76,10 +76,29 @@ class AtlantisClient:
         public_key = self.get_public_key()
 
         try:
-            return jwt.decode(token, public_key, audience=self.client_id)
+            return jwt.decode(id_token, public_key, audience=self.client_id)
         except Exception as err:
             raise InvalidTokenError(err)
 
+    def introspect_token(self, access_token):
+        """Verifica se o access_token está válido
+
+        :param access_token: Token do usuário gerado pelo Atlantis
+        :type access_token: str
+        :return: Retorna dados do token: ``active``, ``email``, ``scope``, ``client_id``,``exp``, etc..
+        :rtype: dict
+        """
+        response = requests.post(
+            '{}/api/instrospect'.format(self.atlantis_url),
+            data={
+                'token': access_token,
+                'token_type_hint': 'access_token',
+                'client_id': self.client_id,
+                'client_secret': self.client_secret
+            })
+        response.raise_for_status()
+        return response.json()
+
 
 class InvalidTokenError(RuntimeError):
     pass
