@@ -31,7 +31,7 @@ class TorpedoClient:
         :param subject: Assunto do email
         :type subject: str
         :param template_name: Nome do template do Torpedo
-            (`Veja os templates disponíveis <http://sta.spacetimedocs.com/torpedo>`_).
+            (`Veja os templates disponíveis <http://notifications.spacetimeanalytics.com>`_).
         :type template_name: str
         :param data: Dicionário de dados para popular o email
         :type data: dict, optional
